django-hug
==========================
Package for working with Django urls/views and request/response validation in more convenient way. 
Inspired by beautiful [hug](https://github.com/timothycrosley/hug).

#### To start example app
```bash
make venv
source activate
cd example
./manage.py runserver
```

Attention! Work In Progress
==
